@@ -131,7 +131,8 @@ report_table.aov <- function(x, ...) {
 
   table <- datawizard::data_remove(
     table_full,
-    datawizard::data_find(table_full, select = "(_CI_low|_CI_high)$", regex = TRUE)
+    select = "(_CI_low|_CI_high)$",
+    regex = TRUE
   )
 
   as.report_table(
