@@ -9,8 +9,6 @@
 #'
 #' @examples
 #' \donttest{
-#' library(report)
-#'
 #' # Miscellaneous
 #' r <- report_table(sessionInfo())
 #' r
@@ -23,7 +21,7 @@
 #' report_table(iris)
 #'
 #' # h-tests
-#' report_table(t.test(mpg ~ am, data = mtcars))
+#' report_table(t.test(mtcars$mpg ~ mtcars$am))
 #'
 #' # ANOVAs
 #' report_table(aov(Sepal.Length ~ Species, data = iris))
@@ -31,27 +29,33 @@
 #' # GLMs
 #' report_table(lm(Sepal.Length ~ Petal.Length * Species, data = iris))
 #' report_table(glm(vs ~ disp, data = mtcars, family = "binomial"))
+#' }
 #'
+#' @examplesIf requireNamespace("lme4", quietly = TRUE)
+#' \donttest{
 #' # Mixed models
-#' if (require("lme4")) {
-#'   model <- lme4::lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
-#'   report_table(model)
+#' library(lme4)
+#' model <- lme4::lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
+#' report_table(model)
 #' }
 #'
+#' @examplesIf requireNamespace("rstanarm", quietly = TRUE)
+#' \donttest{
 #' # Bayesian models
-#' if (require("rstanarm")) {
-#'   model <- stan_glm(Sepal.Length ~ Species, data = iris, refresh = 0, iter = 600)
-#'   report_table(model, effectsize_method = "basic")
+#' library(rstanarm)
+#' model <- suppressWarnings(stan_glm(Sepal.Length ~ Species, data = iris, refresh = 0, iter = 600))
+#' report_table(model, effectsize_method = "basic")
 #' }
 #'
+#' @examplesIf requireNamespace("lavaan", quietly = TRUE)
+#' \donttest{
 #' # Structural Equation Models (SEM)
-#' if (require("lavaan")) {
-#'   structure <- " ind60 =~ x1 + x2 + x3
-#'                  dem60 =~ y1 + y2 + y3
-#'                  dem60 ~ ind60 "
-#'   model <- lavaan::sem(structure, data = PoliticalDemocracy)
-#'   report_table(model)
-#' }
+#' library(lavaan)
+#' structure <- "ind60 =~ x1 + x2 + x3
+#'               dem60 =~ y1 + y2 + y3
+#'               dem60 ~ ind60"
+#' model <- lavaan::sem(structure, data = PoliticalDemocracy)
+#' suppressWarnings(report_table(model))
 #' }
 #' @export
 report_table <- function(x, ...) {
@@ -122,6 +126,7 @@ format.report_table <- function(x, ...) {
   insight::format_table(x, ...)
 }
 
+
 #' @export
 print.report_table <- function(x, ...) {
   # try to guess appropriate caption and footer
@@ -132,6 +137,27 @@ print.report_table <- function(x, ...) {
 }
 
 
+#' @export
+c.report_table <- function(...) {
+  x <- list(...)
+
+  out <- x[[1]]
+  for (i in 2:length(x)) {
+    out <- datawizard::data_join(out, x[[i]], join = "bind")
+  }
+  out
+}
+
+
+#' @export
+display.report_table <- function(object, ...) {
+  # fix caption
+  if (is.null(list(...)$caption)) {
+    attr(object, "no_caption") <- TRUE
+  }
+  class(object) <- c("report_table", "parameters_model", "data.frame")
+  NextMethod()
+}
 
 
 # helper to create table captions and footer -----------------------
@@ -174,3 +200,10 @@ print.report_table <- function(x, ...) {
 
   footer
 }
+
+
+# Reexports models ------------------------
+
+#' @importFrom insight display
+#' @export
+insight::display
